from django.db import models
import uuid
from django.contrib.auth.models import User
from django.core.validators import RegexValidator, MinLengthValidator, MaxValueValidator, MinValueValidator, MaxLengthValidator

class UserDanantaro(models.Model):
    # is_admin = models.BooleanField(default=False)
    user = models.OneToOneField(User, on_delete=models.CASCADE) 
    # username = models.CharField(
    #     unique=True,
    #     max_length=255,
    #     validators=[RegexValidator(r"^[a-zA-Z0-9.,'_-]+$", message="Hanya huruf, angka, dan karakter ('.', ',', '-', '_') yang diperbolehkan.", code="invalid_username")]
    # )
    name = models.CharField(
        max_length=255, 
        validators=[RegexValidator(r"^[a-zA-Z0-9.,'_-]+$", message="Hanya huruf, angka, dan karakter ('.', ',', '-', '_') yang diperbolehkan.", code="invalid_name")]
    )
    # password = models.CharField(
    #     max_length=255,
    #     validators=[RegexValidator(r"^(?=.*[a-z])(?=.*[0-9])(?=.*[\W_]).+$", message="Password harus terdiri dari huruf, angka, dan karakter spesial.", code="invalid_password")]
    # )
    # password_confirmation = models.CharField(
    #     max_length=255,
    #     validators=[RegexValidator(r"^(?=.*[a-z])(?=.*[0-9])(?=.*[\W_]).+$", message="Password harus terdiri dari huruf, angka, dan karakter spesial.", code="invalid_password")]
    # )
    birth_date = models.DateField()
    phone = models.CharField(
        max_length=15,
        validators=[RegexValidator(r"^\d{8,15}$", message="Nomor HP harus terdiri dari 8 hingga 15 digit angka tanpa simbol '+'.")]
    )
    # email = models.CharField(
    #     unique=True,
    #     max_length=255,
    #     validators=[RegexValidator(r"^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$", message="Format email tidak valid.")]
    # )
    url_blog = models.URLField()
    description = models.TextField(
        validators=[MinLengthValidator(5), MaxLengthValidator(1000)]
    )
    no_rekening = models.CharField(
        max_length=10,
        validators=[RegexValidator(r"^\d{8,10}$", message="Nomor rekening harus terdiri dari 8 hingga 10 digit angka.")]
    )
    credit_score = models.IntegerField(
        validators=[MaxValueValidator(800), MinValueValidator(0)]
    )
    no_card = models.CharField(
        max_length=16,
        validators=[RegexValidator(r"^\d{15,16}$", message="Nomor kartu ATM harus terdiri dari 15 atau 16 digit angka.")]
    )
    EMPLOYEE_STATUS_CHOICES = [
        ('Karyawan', 'Karyawan'),
        ('PNS', 'PNS'),
        ('Mahasiswa', 'Mahasiswa'),
        ('Dosen', 'Dosen'),
    ]
    employee_status = models.CharField(
        max_length=50,
        choices = EMPLOYEE_STATUS_CHOICES,
        validators=[RegexValidator(r"^(Karyawan|PNS|Mahasiswa|Dosen)$", message="Status pekerjaan harus salah satu dari: Karyawan, PNS, Mahasiswa, Dosen.")]
    )
    code_currency = models.CharField(
        max_length=3,
        validators=[RegexValidator(r"^[A-Z]{3}$", message="Kode mata uang harus terdiri dari 3 huruf kapital sesuai ISO 4271.")]
    )
